pub struct PacketBundle {
pub channel_id: u32,
pub length: u16,
}Fields
channel_id: u32length: u16Trait Implementations
Sourceimpl Clone for PacketBundle
impl Clone for PacketBundle
Sourcefn clone(&self) -> PacketBundle
fn clone(&self) -> PacketBundle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Compatible<PacketBundle> for PacketBundle
impl<'a> Compatible<PacketBundle> for PacketBundleLazy<'a>
impl<'a> Compatible<PacketBundleLazy<'a>> for PacketBundle
impl Copy for PacketBundle
Sourceimpl Debug for PacketBundle
impl Debug for PacketBundle
Sourceimpl<'a> Decode<'a> for PacketBundle
impl<'a> Decode<'a> for PacketBundle
fn decode(cursor: &DecodeCursor<'a>) -> DecodeResult<Self>
Sourceimpl Encode for PacketBundle
impl Encode for PacketBundle
fn scratch_len(&self) -> usize
fn encode(&self, cursor: &mut EncodeCursor<'_>)
impl Eq for PacketBundle
Sourceimpl Hash for PacketBundle
impl Hash for PacketBundle
Sourceimpl Ord for PacketBundle
impl Ord for PacketBundle
Sourcefn cmp(&self, other: &PacketBundle) -> Ordering
fn cmp(&self, other: &PacketBundle) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl Owned for PacketBundle
impl Owned for PacketBundle
type Lazy<'a> = PacketBundleLazy<'a>
fn lazy_to_owned(lazy: Self::Lazy<'_>) -> DecodeResult<Self>
Sourceimpl PartialEq for PacketBundle
impl PartialEq for PacketBundle
Sourcefn eq(&self, other: &PacketBundle) -> bool
fn eq(&self, other: &PacketBundle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PacketBundle
impl PartialOrd for PacketBundle
impl StructuralPartialEq for PacketBundle
Sourceimpl<'a> TryFrom<PacketBundleLazy<'a>> for PacketBundle
impl<'a> TryFrom<PacketBundleLazy<'a>> for PacketBundle
Sourcetype Error = DecodeError
type Error = DecodeError
The type returned in the event of a conversion error.