pub struct RuntimeBuilder { /* private fields */ }Implementations
Sourceimpl RuntimeBuilder
impl RuntimeBuilder
Sourcepub fn new_no_local() -> Self
pub fn new_no_local() -> Self
Start building a runtime that is not used on the current thread.
Sourcepub fn new_with_local(spawner: LocalSpawner) -> Self
pub fn new_with_local(spawner: LocalSpawner) -> Self
Start building a runtime can be used on the current thread.
pub fn new_worker_group(&mut self, worker_count: u16) -> WorkerGroup
pub fn start<E: ModrpcExecutor>(self) -> (RuntimeHandle, RuntimeShutdownHandle)